#!/bin/bash

. ./var.sh
. ./io.sh

# logger levels
# error = 1
# warning = 2
# info = 3
# debug = 9

getVar LOGGER_LEVEL 1
LOGGER_LEVEL=$RETURN

getVar LOG_PATH ''
LOG_PATH=$RETURN

ENDCOLOR="\e[0m"

function getLogPath() {
  getVar LOG_PATH ''
  local LOCAL_LOG_PATH=$RETURN

  local YEAR
  YEAR=$(date +%Y)
  LOCAL_LOG_PATH=$(echo "$LOCAL_LOG_PATH" | sed -r "s/%Y/$YEAR/g")

  local MONTH
  MONTH=$(date +%m)
  LOCAL_LOG_PATH=$(echo "$LOCAL_LOG_PATH" | sed -r "s/%m/$MONTH/g")

  local DAY
  DAY=$(date +%d)
  LOCAL_LOG_PATH=$(echo "$LOCAL_LOG_PATH" | sed -r "s/%d/$DAY/g")

  local HOUR
  HOUR=$(date +%H)
  LOCAL_LOG_PATH=$(echo "$LOCAL_LOG_PATH" | sed -r "s/%H/$HOUR/g")

  local MINUTE
  MINUTE=$(date +%M)
  LOCAL_LOG_PATH=$(echo "$LOCAL_LOG_PATH" | sed -r "s/%i/$MINUTE/g")

  RETURN=$LOCAL_LOG_PATH
}

function writeFileLog() {
    getLogPath
    local LOG_PATH=$RETURN
    if [[ -n $LOG_PATH ]]
    then
      filePutContent "$LOG_PATH" "$(date "+%Y.%m.%d %H:%I:%S") [$2] $1"
    fi
}

function error()
{
  echo -e "\e[0m\E[41m\n!\n! [ERROR] $1\n!$ENDCOLOR" >&2
  writeFileLog "$1" "ERROR"
  exit 1
}

function warning()
{
  if [ "$LOGGER_LEVEL" -gt 1 ]; then
    echo -e "\e[0m\E[43m\n!\n! [WARNING] $1\n!$ENDCOLOR" >&2
    writeFileLog "$1" "WARNING"
  fi
}

function info
{
  if [ "$LOGGER_LEVEL" -gt 2 ]; then
    echo -e "\e[0m\E[102m\n!\n! [INFO] $1\n!$ENDCOLOR" >&2
    writeFileLog "$1" "INFO"
  fi
}

function debug
{
  if [ "$LOGGER_LEVEL" -gt 8 ]; then
    echo -e "\e[0m\E[44m\n!\n! [DEBUG] $1\n!$ENDCOLOR" >&2
    writeFileLog "$1" "DEBUG"
  fi
}